#!/usr/bin/env node
import { ESOTranslate } from "./index";
import yargs from 'yargs';

const argv = yargs.options({
  inputDir: {
    type: 'string',
    demandOption: true,
    describe: 'Directory that contains the en.json that will be used as the source for all translations. This directory is also used to search for overrides for other languages.'
  },
  outputDir: {
    type: 'string',
    default: 'lang',
    describe: 'Directory to write the resulting Lua files.'
  },
  langs: {
    type: 'string',
    default: "fr,de",
    describe: 'Use comma separated list of 2 letter language codes. English is the only source language at the moment. Defaults to "fr,de" (DON\'T FORGET TO USE QUOTES!!)'
  },
  key: {
    type: 'string',
    describe: 'Access key to Azure Cognitive Services. Setting \'ESO_TRANSLATOR\' environment variable is preferred method of authentication'
  }
}).argv;

if (!(argv.key || process.env.ESO_TRANSLATOR)) {
  throw new Error('Set `ESO_TRANSLATOR` environment variable or provide via the `key` parameter (less secure)')
} else {
  new ESOTranslate({
    key: argv.key || process.env.ESO_TRANSLATOR || "",
    inputDirectory: argv.inputDir,
    outputDir: argv.outputDir,
    langs: argv.langs.split(",").map(lang => lang.toLowerCase().trim())
  }).translate();
}


